Struct VersionFlags

pub struct VersionFlags { /* private fields */ }
The version flags represents the options that are supported in the library and the EXR file.

Implementations

Source

impl VersionFlags

pub const TILED: VersionFlags

File is tiled

pub const LONG_NAMES: VersionFlags

File contains long attribute or channel names

pub const NON_IMAGE: VersionFlags

File has at least one part which is not a regular scanline image or regular tiled image (that is, it is a deep format)

pub const MULTI_PART_FILE: VersionFlags

File has multiple parts

pub const ALL: VersionFlags

Bitwise OR of all known flags

pub const fn empty() -> VersionFlags

Returns an empty set of flags

pub const fn all() -> VersionFlags

Returns the set containing all flags.

pub const fn bits(&self) -> i32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: i32) -> Option<VersionFlags>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: i32) -> VersionFlags

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: i32) -> VersionFlags

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: VersionFlags) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: VersionFlags) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: VersionFlags)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: VersionFlags)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: VersionFlags)

Toggles the specified flags in-place.

pub fn set(&mut self, other: VersionFlags, value: bool)

Inserts or removes the specified flags depending on the passed value.

Source

impl VersionFlags

pub fn supports_flags(&self) -> bool

The flag object is supported by the bound OpenEXR library.