pub struct VersionFlags { /* private fields */ }Expand description
The version flags represents the options that are supported in the library and the EXR file.
Implementations
Sourceimpl VersionFlags
impl VersionFlags
Sourcepub const TILED: VersionFlags
pub const TILED: VersionFlags
File is tiled
Sourcepub const LONG_NAMES: VersionFlags
pub const LONG_NAMES: VersionFlags
File contains long attribute or channel names
Sourcepub const NON_IMAGE: VersionFlags
pub const NON_IMAGE: VersionFlags
File has at least one part which is not a regular scanline image or regular tiled image (that is, it is a deep format)
Sourcepub const MULTI_PART_FILE: VersionFlags
pub const MULTI_PART_FILE: VersionFlags
File has multiple parts
Sourcepub const ALL: VersionFlags
pub const ALL: VersionFlags
Bitwise OR of all known flags
Sourcepub const fn empty() -> VersionFlags
pub const fn empty() -> VersionFlags
Returns an empty set of flags
Sourcepub const fn all() -> VersionFlags
pub const fn all() -> VersionFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: i32) -> Option<VersionFlags>
pub fn from_bits(bits: i32) -> Option<VersionFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> VersionFlags
pub const fn from_bits_truncate(bits: i32) -> VersionFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> VersionFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> VersionFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: VersionFlags) -> bool
pub const fn intersects(&self, other: VersionFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: VersionFlags) -> bool
pub const fn contains(&self, other: VersionFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: VersionFlags)
pub fn insert(&mut self, other: VersionFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: VersionFlags)
pub fn remove(&mut self, other: VersionFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: VersionFlags)
pub fn toggle(&mut self, other: VersionFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: VersionFlags, value: bool)
pub fn set(&mut self, other: VersionFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourceimpl VersionFlags
impl VersionFlags
Sourcepub fn supports_flags(&self) -> bool
pub fn supports_flags(&self) -> bool
The flag object is supported by the bound OpenEXR library.